/* NO USER CONFIGURABLE PARAMETERS HERE! */

/* Path Integral Monte Carlo code developed by A. Balaz 
   (antun@ipb.ac.rs) for the paper:
         
   "Systematic Speedup in the Convergence of Path Integrals"
   by A. Bogojevic, A. Balaz, and A. Belic
   Phys. Rev. Lett. 94 (2005) 180403

   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/speedup/

   Public use and modification of this code is allowed providing 
   the above paper is properly acknowledged. The author would be 
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* This file contains code from the Numerical Recipes that is used in our simulation. */

#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#define NR_END 1
#define FREE_ARG char*

int *ivector(long, long);
double *dvector(long, long);
double **dmatrix(long, long, long, long);
void free_ivector(int *, long, long);
void free_dvector(double *, long, long);
void free_dmatrix(double **, long, long, long, long);
void nrerror(char *);

int *ivector(long nl, long nh)
/* allocate an int vector with subscript range v[nl..nh] */
{
   int *v;

   v = (int *)malloc((size_t) ((nh - nl + 1 + NR_END) * sizeof(int)));
   if(!v) nrerror("allocation failure in ivector()");
   return v - nl + NR_END;
}
/* (C) Copr. 1986-92 Numerical Recipes Software. */

double *dvector(long nl, long nh)
/* allocate a double vector with subscript range v[nl..nh] */
{
   double *v;

   v = (double *)malloc((size_t) ((nh - nl + 1 + NR_END) * sizeof(double)));
   if(!v) nrerror("allocation failure in ldvector()");
   return v - nl + NR_END;
}
/* (C) Copr. 1986-92 Numerical Recipes Software. */

void free_ivector(int *v, long nl, long nh)
/* free an int vector allocated with ivector() */
{
   free((FREE_ARG) (v + nl - NR_END));
}
/* (C) Copr. 1986-92 Numerical Recipes Software. */

void free_dvector(double *v, long nl, long nh)
/* free a double vector allocated with dvector() */
{
   free((FREE_ARG) (v + nl - NR_END));
}
/* (C) Copr. 1986-92 Numerical Recipes Software. */

void nrerror(char *error_text)
/* Numerical Recipes standard error handler */
{
   fprintf(stderr, "Numerical Recipes run-time error...\n");
   fprintf(stderr, "%s\n",error_text);
   fprintf(stderr, "...now exiting to system...\n");
   exit(EXIT_FAILURE);
}
/* (C) Copr. 1986-92 Numerical Recipes Software. */
